@@ -5,9 +5,9 @@ from pdchaosazure import load_secrets, auth
 
 
 def init_client(experiment_secrets: Secrets) -> ResourceGraphClient:
-    secrets = load_secrets(experiment_secrets)
+    secrets = load_secrets()
 
-    with auth(secrets) as authentication:
+    with auth(secrets) as credential:
         base_url = secrets.get('cloud').endpoints.resource_manager
-        client = ResourceGraphClient(credentials=authentication, base_url=base_url)
+        client = ResourceGraphClient(credential=credential, base_url=base_url)
         return client
