@@ -8,42 +8,30 @@ from pdchaosazure.webapp.constants import RES_TYPE_WEBAPP
 def describe_webapps(filter: str = None,
                      configuration: Configuration = None,
                      secrets: Secrets = None):
-    """
-    Describe Azure web apps.
+    """Describe web app instances.
 
     Parameters
     ----------
-    filter : str
-        Filter the web apps. If the filter is omitted all web apps in
-        the subscription will be selected for the probe.
-        Filtering example:
-        'where resourceGroup=="myresourcegroup" and name="myresourcename"'
+    filter : str, optional
+        Filter the web app instance(s). If omitted a random instance from your subscription is selected.
     """
     logger.debug(
-        "Start describe_webapps: configuration='{}', filter='{}'".format(
-            configuration, filter))
+        "Starting {}: configuration='{}', filter='{}'".format(describe_webapps.__name__, configuration, filter))
 
-    webapps = fetch_resources(filter, RES_TYPE_WEBAPP, secrets, configuration)
-    return webapps
+    return fetch_resources(filter, RES_TYPE_WEBAPP, secrets, configuration)
 
 
 def count_webapps(filter: str = None,
                   configuration: Configuration = None,
                   secrets: Secrets = None) -> int:
-    """
-    Return count of Azure web apps.
+    """Return count of web app instances.
 
     Parameters
     ----------
-    filter : str
-        Filter the web apps. If the filter is omitted all web apps in
-        the subscription will be selected for the probe.
-        Filtering example:
-        'where resourceGroup=="myresourcegroup" and name="myresourcename"'
+    filter : str, optional
+        Filter the web app instance(s). If omitted a random instance from your subscription is selected.
     """
-    logger.debug(
-        "Start count_machines: configuration='{}', filter='{}'".format(
-            configuration, filter))
+    logger.debug("Start {}: configuration='{}', filter='{}'".format(count_webapps.__name__, configuration, filter))
 
     webapps = fetch_resources(filter, RES_TYPE_WEBAPP, secrets, configuration)
     return len(webapps)
